Contributing Guidelines
=========================

Wanna contribute to this project? Yay, here is how!

Filing Issues
================

If you have a question about python-clickclick, or have problems using it, please read the README before filing an issue. Also, double-check with the current issues on our `Issues Tracker`_.

Contributing a Pull Request
==============================

1. Submit a comment to the relevant issue or create a new issue describing your proposed change.
2. Do a fork, develop and test your code changes.
3. Include documentation.
4. Submit a pull request.

You'll get feedback about your pull request as soon as possible.

Happy hacking ;-)

.. _Issues Tracker: https://github.com/zalando/python-clickclick/issues
